@@ -47,6 +47,10 @@ impl f32x8 {
 unsafe impl Zeroable for f32x8 {}
 unsafe impl Pod for f32x8 {}
 
+impl AlignTo for f32x8 {
+  type Elem = f32;
+}
+
 impl Add for f32x8 {
   type Output = Self;
   #[inline]
@@ -233,14 +237,14 @@ impl BitXor for f32x8 {
 impl CmpEq for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_eq(self, rhs: Self) -> Self::Output {
+  fn simd_eq(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(EqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_eq(rhs.a),
-          b : self.b.cmp_eq(rhs.b),
+          a : self.a.simd_eq(rhs.a),
+          b : self.b.simd_eq(rhs.b),
         }
       }
     }
@@ -250,14 +254,14 @@ impl CmpEq for f32x8 {
 impl CmpGe for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_ge(self, rhs: Self) -> Self::Output {
+  fn simd_ge(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(GreaterEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_ge(rhs.a),
-          b : self.b.cmp_ge(rhs.b),
+          a : self.a.simd_ge(rhs.a),
+          b : self.b.simd_ge(rhs.b),
         }
       }
     }
@@ -267,14 +271,14 @@ impl CmpGe for f32x8 {
 impl CmpGt for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_gt(self, rhs: Self) -> Self::Output {
+  fn simd_gt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(GreaterThanOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_gt(rhs.a),
-          b : self.b.cmp_gt(rhs.b),
+          a : self.a.simd_gt(rhs.a),
+          b : self.b.simd_gt(rhs.b),
         }
       }
     }
@@ -284,14 +288,14 @@ impl CmpGt for f32x8 {
 impl CmpNe for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_ne(self, rhs: Self) -> Self::Output {
+  fn simd_ne(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(NotEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_ne(rhs.a),
-          b : self.b.cmp_ne(rhs.b),
+          a : self.a.simd_ne(rhs.a),
+          b : self.b.simd_ne(rhs.b),
         }
       }
     }
@@ -301,14 +305,14 @@ impl CmpNe for f32x8 {
 impl CmpLe for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_le(self, rhs: Self) -> Self::Output {
+  fn simd_le(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(LessEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_le(rhs.a),
-          b : self.b.cmp_le(rhs.b),
+          a : self.a.simd_le(rhs.a),
+          b : self.b.simd_le(rhs.b),
         }
       }
     }
@@ -318,14 +322,14 @@ impl CmpLe for f32x8 {
 impl CmpLt for f32x8 {
   type Output = Self;
   #[inline]
-  fn cmp_lt(self, rhs: Self) -> Self::Output {
+  fn simd_lt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { avx: cmp_op_mask_m256::<{cmp_op!(LessThanOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_lt(rhs.a),
-          b : self.b.cmp_lt(rhs.b),
+          a : self.a.simd_lt(rhs.a),
+          b : self.b.simd_lt(rhs.b),
         }
       }
     }
@@ -493,7 +497,7 @@ impl f32x8 {
     let shifted_exp_mask = u32x8::from(0xFF000000);
     let u: u32x8 = cast(self);
     let shift_u = u << 1_u64;
-    let out = !(shift_u & shifted_exp_mask).cmp_eq(shifted_exp_mask);
+    let out = !(shift_u & shifted_exp_mask).simd_eq(shifted_exp_mask);
     cast(out)
   }
   #[inline]
@@ -502,7 +506,7 @@ impl f32x8 {
     let shifted_inf = u32x8::from(0xFF000000);
     let u: u32x8 = cast(self);
     let shift_u = u << 1_u64;
-    let out = (shift_u).cmp_eq(shifted_inf);
+    let out = (shift_u).simd_eq(shifted_inf);
     cast(out)
   }
 
@@ -548,9 +552,9 @@ impl f32x8 {
     pick! {
       if #[cfg(target_feature="avx")] {
         // Based on: https://github.com/v8/v8/blob/210987a552a2bf2a854b0baa9588a5959ff3979d/src/codegen/shared-ia32-x64/macro-assembler-shared-ia32-x64.h#L489-L504
-        let non_nan_mask = self.cmp_eq(self);
+        let non_nan_mask = self.simd_eq(self);
         let non_nan = self & non_nan_mask;
-        let flip_to_max: i32x8 = cast(self.cmp_ge(Self::splat(2147483648.0)));
+        let flip_to_max: i32x8 = cast(self.simd_ge(Self::splat(2147483648.0)));
         let cast: i32x8 = cast(convert_to_i32_m256i_from_m256(non_nan.avx));
         flip_to_max ^ cast
       } else {
@@ -589,9 +593,9 @@ impl f32x8 {
     pick! {
         if #[cfg(target_feature="avx")] {
         // Based on: https://github.com/v8/v8/blob/210987a552a2bf2a854b0baa9588a5959ff3979d/src/codegen/shared-ia32-x64/macro-assembler-shared-ia32-x64.h#L489-L504
-        let non_nan_mask = self.cmp_eq(self);
+        let non_nan_mask = self.simd_eq(self);
         let non_nan = self & non_nan_mask;
-        let flip_to_max: i32x8 = cast(self.cmp_ge(Self::splat(2147483648.0)));
+        let flip_to_max: i32x8 = cast(self.simd_ge(Self::splat(2147483648.0)));
         let cast: i32x8 = cast(convert_truncate_to_i32_m256i_from_m256(non_nan.avx));
         flip_to_max ^ cast
       } else {
@@ -602,6 +606,30 @@ impl f32x8 {
       }
     }
   }
+  /// Performs a multiply-add operation: `self * m + a`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and add operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses `vfmadd` (single rounding, best
+  ///   accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `(self * m) + a` (two roundings)
+  /// - Other platforms: Delegates to [`f32x4`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f32x8;
+  /// let a = f32x8::from([1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0]);
+  /// let b = f32x8::from([2.0; 8]);
+  /// let c = f32x8::from([10.0; 8]);
+  ///
+  /// let result = a.mul_add(b, c);
+  ///
+  /// let expected = f32x8::from([12.0, 14.0, 16.0, 18.0, 20.0, 22.0, 24.0, 26.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_add(self, m: Self, a: Self) -> Self {
@@ -620,24 +648,72 @@ impl f32x8 {
     }
   }
 
+  /// Performs a multiply-subtract operation: `self * m - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and subtract operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses `vfmsub` (single rounding, best
+  ///   accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `(self * m) - s` (two roundings)
+  /// - Other platforms: Delegates to [`f32x4`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f32x8;
+  /// let a = f32x8::from([10.0; 8]);
+  /// let b = f32x8::from([2.0; 8]);
+  /// let c = f32x8::from([5.0; 8]);
+  ///
+  /// let result = a.mul_sub(b, c);
+  ///
+  /// let expected = f32x8::from([15.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_sub(self, m: Self, s: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="avx",target_feature="fma"))] {
-        Self { avx: fused_mul_sub_m256(self.avx, m.avx, a.avx) }
+        Self { avx: fused_mul_sub_m256(self.avx, m.avx, s.avx) }
       } else if #[cfg(target_feature="avx")] {
         // still want to use 256 bit ops
-        (self * m) - a
+        (self * m) - s
       } else {
         Self {
-          a : self.a.mul_sub(m.a, a.a),
-          b : self.b.mul_sub(m.b, a.b),
+          a : self.a.mul_sub(m.a, s.a),
+          b : self.b.mul_sub(m.b, s.b),
         }
       }
     }
   }
 
+  /// Performs a negative multiply-add operation: `a - (self * m)`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses `vfnmadd` (single rounding, best
+  ///   accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `a - (self * m)` (two roundings)
+  /// - Other platforms: Delegates to [`f32x4`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f32x8;
+  /// let a = f32x8::from([3.0; 8]);
+  /// let b = f32x8::from([2.0; 8]);
+  /// let c = f32x8::from([10.0; 8]);
+  ///
+  /// let result = a.mul_neg_add(b, c);
+  ///
+  /// let expected = f32x8::from([4.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_neg_add(self, m: Self, a: Self) -> Self {
@@ -656,19 +732,43 @@ impl f32x8 {
     }
   }
 
+  /// Performs a negative multiply-subtract operation: `-(self * m) - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses `vfnmsub` (single rounding, best
+  ///   accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `-(self * m) - s` (two roundings)
+  /// - Other platforms: Delegates to [`f32x4`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f32x8;
+  /// let a = f32x8::from([3.0; 8]);
+  /// let b = f32x8::from([2.0; 8]);
+  /// let c = f32x8::from([1.0; 8]);
+  ///
+  /// let result = a.mul_neg_sub(b, c);
+  ///
+  /// let expected = f32x8::from([-7.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_neg_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_neg_sub(self, m: Self, s: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="avx",target_feature="fma"))] {
-        Self { avx: fused_mul_neg_sub_m256(self.avx, m.avx, a.avx) }
+        Self { avx: fused_mul_neg_sub_m256(self.avx, m.avx, s.avx) }
       } else if #[cfg(target_feature="avx")] {
         // still want to use 256 bit ops
-        -(self * m) - a
+        -(self * m) - s
       } else {
         Self {
-          a : self.a.mul_neg_sub(m.a, a.a),
-          b : self.b.mul_neg_sub(m.b, a.b),
+          a : self.a.mul_neg_sub(m.a, s.a),
+          b : self.b.mul_neg_sub(m.b, s.b),
         }
       }
     }
@@ -698,7 +798,7 @@ impl f32x8 {
     const_f32_as_f32x8!(P0asinf, 1.6666752422E-1);
 
     let xa = self.abs();
-    let big = xa.cmp_ge(f32x8::splat(0.5));
+    let big = xa.simd_ge(f32x8::splat(0.5));
 
     let x1 = f32x8::splat(0.5) * (f32x8::ONE - xa);
     let x2 = xa * xa;
@@ -714,7 +814,7 @@ impl f32x8 {
     let z1 = z + z;
 
     // acos
-    let z3 = self.cmp_lt(f32x8::ZERO).blend(f32x8::PI - z1, z1);
+    let z3 = self.simd_lt(f32x8::ZERO).blend(f32x8::PI - z1, z1);
     let z4 = f32x8::FRAC_PI_2 - z.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -738,7 +838,7 @@ impl f32x8 {
     const_f32_as_f32x8!(P0asinf, 1.6666752422E-1);
 
     let xa = self.abs();
-    let big = xa.cmp_ge(f32x8::splat(0.5));
+    let big = xa.simd_ge(f32x8::splat(0.5));
 
     let x1 = f32x8::splat(0.5) * (f32x8::ONE - xa);
     let x2 = xa * xa;
@@ -773,7 +873,7 @@ impl f32x8 {
     const_f32_as_f32x8!(P0asinf, 1.6666752422E-1);
 
     let xa = self.abs();
-    let big = xa.cmp_ge(f32x8::splat(0.5));
+    let big = xa.simd_ge(f32x8::splat(0.5));
 
     let x1 = f32x8::splat(0.5) * (f32x8::ONE - xa);
     let x2 = xa * xa;
@@ -789,7 +889,7 @@ impl f32x8 {
     let z1 = z + z;
 
     // acos
-    let z3 = self.cmp_lt(f32x8::ZERO).blend(f32x8::PI - z1, z1);
+    let z3 = self.simd_lt(f32x8::ZERO).blend(f32x8::PI - z1, z1);
     let z4 = f32x8::FRAC_PI_2 - z.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -810,8 +910,8 @@ impl f32x8 {
     // small:  z = t / 1.0;
     // medium: z = (t-1.0) / (t+1.0);
     // big:    z = -1.0 / t;
-    let notsmal = t.cmp_ge(Self::SQRT_2 - Self::ONE);
-    let notbig = t.cmp_le(Self::SQRT_2 + Self::ONE);
+    let notsmal = t.simd_ge(Self::SQRT_2 - Self::ONE);
+    let notbig = t.simd_le(Self::SQRT_2 + Self::ONE);
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -848,7 +948,7 @@ impl f32x8 {
     // move in first octant
     let x1 = x.abs();
     let y1 = y.abs();
-    let swapxy = y1.cmp_gt(x1);
+    let swapxy = y1.simd_gt(x1);
     // swap x and y if y1 > x1
     let mut x2 = swapxy.blend(y1, x1);
     let mut y2 = swapxy.blend(x1, y1);
@@ -866,7 +966,7 @@ impl f32x8 {
 
     // small:  z = t / 1.0;
     // medium: z = (t-1.0) / (t+1.0);
-    let notsmal = t.cmp_ge(Self::SQRT_2 - Self::ONE);
+    let notsmal = t.simd_ge(Self::SQRT_2 - Self::ONE);
 
     let a = notsmal.blend(t - Self::ONE, t);
     let b = notsmal.blend(t + Self::ONE, Self::ONE);
@@ -881,7 +981,7 @@ impl f32x8 {
 
     // move back in place
     re = swapxy.blend(Self::FRAC_PI_2 - re, re);
-    re = ((x | y).cmp_eq(Self::ZERO)).blend(Self::ZERO, re);
+    re = ((x | y).simd_eq(Self::ZERO)).blend(Self::ZERO, re);
     re = (x.sign_bit()).blend(Self::PI - re, re);
 
     // get sign bit
@@ -923,9 +1023,9 @@ impl f32x8 {
     let mut c = polynomial_2!(x2, P0cosf, P1cosf, P2cosf) * (x2 * x2)
       + f32x8::from(0.5).mul_neg_add(x2, f32x8::from(1.0));
 
-    let swap = !(q & i32x8::from(1)).cmp_eq(i32x8::from(0));
+    let swap = !(q & i32x8::from(1)).simd_eq(i32x8::from(0));
 
-    let mut overflow: f32x8 = cast(q.cmp_gt(i32x8::from(0x2000000)));
+    let mut overflow: f32x8 = cast(q.simd_gt(i32x8::from(0x2000000)));
     overflow &= xa.is_finite();
     s = overflow.blend(f32x8::from(0.0), s);
     c = overflow.blend(f32x8::from(1.0), c);
@@ -1016,12 +1116,12 @@ impl f32x8 {
   }
   #[inline]
   #[must_use]
-  pub fn move_mask(self) -> i32 {
+  pub fn to_bitmask(self) -> u32 {
     pick! {
       if #[cfg(target_feature="avx")] {
-        move_mask_m256(self.avx)
+        move_mask_m256(self.avx) as u32
       } else {
-        (self.b.move_mask() << 4) | self.a.move_mask()
+        (self.b.to_bitmask() << 4) | self.a.to_bitmask()
       }
     }
   }
@@ -1084,7 +1184,7 @@ impl f32x8 {
     let n2 = Self::vm_pow2n(r);
     let z = (z + Self::ONE) * n2;
     // check for overflow
-    let in_range = self.abs().cmp_lt(max_x);
+    let in_range = self.abs().simd_lt(max_x);
     let in_range = in_range & self.is_finite();
     in_range.blend(z, Self::ZERO)
   }
@@ -1113,7 +1213,7 @@ impl f32x8 {
   fn is_zero_or_subnormal(self) -> Self {
     let t = cast::<_, i32x8>(self);
     let t = t & i32x8::splat(0x7F800000);
-    i32x8::round_float(t.cmp_eq(i32x8::splat(0)))
+    i32x8::round_float(t.simd_eq(i32x8::splat(0)))
   }
   #[inline]
   fn infinity() -> Self {
@@ -1131,7 +1231,7 @@ impl f32x8 {
   pub fn sign_bit(self) -> Self {
     let t1 = cast::<_, i32x8>(self);
     let t2 = t1 >> 31;
-    !cast::<_, f32x8>(t2).cmp_eq(f32x8::ZERO)
+    !cast::<_, f32x8>(t2).simd_eq(f32x8::ZERO)
   }
 
   /// horizontal add of all the elements of the vector
@@ -1178,7 +1278,7 @@ impl f32x8 {
     let x1 = self;
     let x = Self::fraction_2(x1);
     let e = Self::exponent(x1);
-    let mask = x.cmp_gt(Self::SQRT_2 * HALF);
+    let mask = x.simd_gt(Self::SQRT_2 * HALF);
     let x = (!mask).blend(x + x, x);
     let fe = mask.blend(e + Self::ONE, e);
     let x = x - Self::ONE;
@@ -1189,7 +1289,7 @@ impl f32x8 {
     let res = res + x2.mul_neg_add(HALF, x);
     let res = fe.mul_add(LN2F_HI, res);
     let overflow = !self.is_finite();
-    let underflow = x1.cmp_lt(VM_SMALLEST_NORMAL);
+    let underflow = x1.simd_lt(VM_SMALLEST_NORMAL);
     let mask = overflow | underflow;
     if !mask.any() {
       res
@@ -1237,7 +1337,7 @@ impl f32x8 {
 
     let x1 = self.abs();
     let x = x1.fraction_2();
-    let mask = x.cmp_gt(f32x8::SQRT_2 * f32x8::HALF);
+    let mask = x.simd_gt(f32x8::SQRT_2 * f32x8::HALF);
     let x = (!mask).blend(x + x, x);
 
     let x = x - f32x8::ONE;
@@ -1274,10 +1374,10 @@ impl f32x8 {
     let ei = cast::<_, i32x8>(ee.round_int());
     let ej = cast::<_, i32x8>(ei + (cast::<_, i32x8>(z) >> 23));
 
-    let overflow = cast::<_, f32x8>(ej.cmp_gt(i32x8::splat(0x0FF)))
-      | (ee.cmp_gt(f32x8::splat(300.0)));
-    let underflow = cast::<_, f32x8>(ej.cmp_lt(i32x8::splat(0x000)))
-      | (ee.cmp_lt(f32x8::splat(-300.0)));
+    let overflow = cast::<_, f32x8>(ej.simd_gt(i32x8::splat(0x0FF)))
+      | (ee.simd_gt(f32x8::splat(300.0)));
+    let underflow = cast::<_, f32x8>(ej.simd_lt(i32x8::splat(0x000)))
+      | (ee.simd_lt(f32x8::splat(-300.0)));
 
     // Add exponent by integer addition
     let z = cast::<_, f32x8>(cast::<_, i32x8>(z) + (ei << 23));
@@ -1288,9 +1388,9 @@ impl f32x8 {
     // Check for self == 0
     let x_zero = self.is_zero_or_subnormal();
     let z = x_zero.blend(
-      y.cmp_lt(f32x8::ZERO).blend(
+      y.simd_lt(f32x8::ZERO).blend(
         Self::infinity(),
-        y.cmp_eq(f32x8::ZERO).blend(f32x8::ONE, f32x8::ZERO),
+        y.simd_eq(f32x8::ZERO).blend(f32x8::ONE, f32x8::ZERO),
       ),
       z,
     );
@@ -1298,13 +1398,13 @@ impl f32x8 {
     let x_sign = self.sign_bit();
     let z = if x_sign.any() {
       // Y into an integer
-      let yi = y.cmp_eq(y.round());
+      let yi = y.simd_eq(y.round());
 
       // Is y odd?
       let y_odd = cast::<_, i32x8>(y.round_int() << 31).round_float();
 
       let z1 =
-        yi.blend(z | y_odd, self.cmp_eq(Self::ZERO).blend(z, Self::nan_pow()));
+        yi.blend(z | y_odd, self.simd_eq(Self::ZERO).blend(z, Self::nan_pow()));
 
       x_sign.blend(z1, z)
     } else {
@@ -1374,14 +1474,14 @@ impl f32x8 {
         #[inline(always)]
         fn transpose_column(data: &[f32x8; 8], index: usize) -> f32x8 {
           f32x8::new([
-            data[0].as_array_ref()[index],
-            data[1].as_array_ref()[index],
-            data[2].as_array_ref()[index],
-            data[3].as_array_ref()[index],
-            data[4].as_array_ref()[index],
-            data[5].as_array_ref()[index],
-            data[6].as_array_ref()[index],
-            data[7].as_array_ref()[index],
+            data[0].as_array()[index],
+            data[1].as_array()[index],
+            data[2].as_array()[index],
+            data[3].as_array()[index],
+            data[4].as_array()[index],
+            data[5].as_array()[index],
+            data[6].as_array()[index],
+            data[7].as_array()[index],
           ])
         }
 
@@ -1405,12 +1505,12 @@ impl f32x8 {
   }
 
   #[inline]
-  pub fn as_array_ref(&self) -> &[f32; 8] {
+  pub fn as_array(&self) -> &[f32; 8] {
     cast_ref(self)
   }
 
   #[inline]
-  pub fn as_array_mut(&mut self) -> &mut [f32; 8] {
+  pub fn as_mut_array(&mut self) -> &mut [f32; 8] {
     cast_mut(self)
   }
 
@@ -1421,14 +1521,14 @@ impl f32x8 {
         Self { avx: convert_to_m256_from_i32_m256i(v.avx2) }
       } else {
         Self::new([
-            v.as_array_ref()[0] as f32,
-            v.as_array_ref()[1] as f32,
-            v.as_array_ref()[2] as f32,
-            v.as_array_ref()[3] as f32,
-            v.as_array_ref()[4] as f32,
-            v.as_array_ref()[5] as f32,
-            v.as_array_ref()[6] as f32,
-            v.as_array_ref()[7] as f32,
+            v.as_array()[0] as f32,
+            v.as_array()[1] as f32,
+            v.as_array()[2] as f32,
+            v.as_array()[3] as f32,
+            v.as_array()[4] as f32,
+            v.as_array()[5] as f32,
+            v.as_array()[6] as f32,
+            v.as_array()[7] as f32,
           ])
       }
     }
