@@ -88,6 +88,10 @@ impl f64x2 {
 unsafe impl Zeroable for f64x2 {}
 unsafe impl Pod for f64x2 {}
 
+impl AlignTo for f64x2 {
+  type Elem = f64;
+}
+
 impl Add for f64x2 {
   type Output = Self;
   #[inline]
@@ -302,7 +306,7 @@ impl BitXor for f64x2 {
 impl CmpEq for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_eq(self, rhs: Self) -> Self::Output {
+  fn simd_eq(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_eq_mask_m128d(self.sse, rhs.sse) }
@@ -323,7 +327,7 @@ impl CmpEq for f64x2 {
 impl CmpGe for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_ge(self, rhs: Self) -> Self::Output {
+  fn simd_ge(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_ge_mask_m128d(self.sse, rhs.sse) }
@@ -344,7 +348,7 @@ impl CmpGe for f64x2 {
 impl CmpGt for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_gt(self, rhs: Self) -> Self::Output {
+  fn simd_gt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")] {
         Self { sse: cmp_op_mask_m128d::<{cmp_op!(GreaterThanOrdered)}>(self.sse, rhs.sse) }
@@ -367,7 +371,7 @@ impl CmpGt for f64x2 {
 impl CmpNe for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_ne(self, rhs: Self) -> Self::Output {
+  fn simd_ne(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_neq_mask_m128d(self.sse, rhs.sse) }
@@ -388,7 +392,7 @@ impl CmpNe for f64x2 {
 impl CmpLe for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_le(self, rhs: Self) -> Self::Output {
+  fn simd_le(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_le_mask_m128d(self.sse, rhs.sse) }
@@ -409,7 +413,7 @@ impl CmpLe for f64x2 {
 impl CmpLt for f64x2 {
   type Output = Self;
   #[inline]
-  fn cmp_lt(self, rhs: Self) -> Self::Output {
+  fn simd_lt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_lt_mask_m128d(self.sse, rhs.sse) }
@@ -653,7 +657,7 @@ impl f64x2 {
     let shifted_exp_mask = u64x2::from(0xFFE0000000000000);
     let u: u64x2 = cast(self);
     let shift_u = u << 1_u64;
-    let out = !(shift_u & shifted_exp_mask).cmp_eq(shifted_exp_mask);
+    let out = !(shift_u & shifted_exp_mask).simd_eq(shifted_exp_mask);
     cast(out)
   }
   #[inline]
@@ -662,7 +666,7 @@ impl f64x2 {
     let shifted_inf = u64x2::from(0xFFE0000000000000);
     let u: u64x2 = cast(self);
     let shift_u = u << 1_u64;
-    let out = (shift_u).cmp_eq(shifted_inf);
+    let out = (shift_u).simd_eq(shifted_inf);
     cast(out)
   }
 
@@ -689,50 +693,156 @@ impl f64x2 {
     let rounded: [f64; 2] = cast(self.round());
     cast([rounded[0] as i64, rounded[1] as i64])
   }
+  /// Performs a multiply-add operation: `self * m + a`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and add operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with FMA: Uses `vfmadd` (single rounding, best
+  ///   accuracy)
+  /// - On ARM64 with NEON: Uses `vfmaq_f64` (single rounding, best accuracy)
+  /// - Without FMA support: Uses `(self * m) + a` (two roundings)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x2;
+  /// let a = f64x2::from([1.0, 2.0]);
+  /// let b = f64x2::from([3.0, 4.0]);
+  /// let c = f64x2::from([5.0, 6.0]);
+  ///
+  /// let result = a.mul_add(b, c);
+  ///
+  /// let expected = f64x2::from([8.0, 14.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_add(self, m: Self, a: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="fma"))] {
         Self { sse: fused_mul_add_m128d(self.sse, m.sse, a.sse) }
+      } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))] {
+        unsafe { Self { neon: vfmaq_f64(a.neon, self.neon, m.neon) } }
       } else {
         (self * m) + a
       }
     }
   }
 
+  /// Performs a multiply-subtract operation: `self * m - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and subtract operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with FMA: Uses `vfmsub` (single rounding, best
+  ///   accuracy)
+  /// - On ARM64 with NEON: Uses `vfmaq_f64(-s, self, m)` (single rounding, best
+  ///   accuracy)
+  /// - Without FMA support: Uses `(self * m) - s` (two roundings)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x2;
+  /// let a = f64x2::from([10.0, 20.0]);
+  /// let b = f64x2::from([2.0, 3.0]);
+  /// let c = f64x2::from([5.0, 10.0]);
+  ///
+  /// let result = a.mul_sub(b, c);
+  ///
+  /// let expected = f64x2::from([15.0, 50.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_sub(self, m: Self, s: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="fma"))] {
-        Self { sse: fused_mul_sub_m128d(self.sse, m.sse, a.sse) }
+        Self { sse: fused_mul_sub_m128d(self.sse, m.sse, s.sse) }
+      } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))] {
+        unsafe { Self { neon: vfmaq_f64(vnegq_f64(s.neon), self.neon, m.neon) } }
       } else {
-        (self * m) - a
+        (self * m) - s
       }
     }
   }
 
+  /// Performs a negative multiply-add operation: `a - (self * m)`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with FMA: Uses `vfnmadd` (single rounding, best
+  ///   accuracy)
+  /// - On ARM64 with NEON: Uses `vfmsq_f64` (single rounding, best accuracy)
+  /// - Without FMA support: Uses `a - (self * m)` (two roundings)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x2;
+  /// let a = f64x2::from([3.0, 4.0]);
+  /// let b = f64x2::from([2.0, 2.0]);
+  /// let c = f64x2::from([10.0, 20.0]);
+  ///
+  /// let result = a.mul_neg_add(b, c);
+  ///
+  /// let expected = f64x2::from([4.0, 12.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_neg_add(self, m: Self, a: Self) -> Self {
     pick! {
         if #[cfg(all(target_feature="fma"))] {
           Self { sse: fused_mul_neg_add_m128d(self.sse, m.sse, a.sse) }
+        } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))] {
+          unsafe { Self { neon: vfmsq_f64(a.neon, self.neon, m.neon) } }
         } else {
           a - (self * m)
         }
     }
   }
 
+  /// Performs a negative multiply-subtract operation: `-(self * m) - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with FMA: Uses `vfnmsub` (single rounding, best
+  ///   accuracy)
+  /// - On ARM64 with NEON: Uses `-(vfmaq_f64(s, self, m))` (single rounding,
+  ///   best accuracy)
+  /// - Without FMA support: Uses `-(self * m) - s` (two roundings)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x2;
+  /// let a = f64x2::from([3.0, 4.0]);
+  /// let b = f64x2::from([2.0, 2.0]);
+  /// let c = f64x2::from([1.0, 2.0]);
+  ///
+  /// let result = a.mul_neg_sub(b, c);
+  ///
+  /// let expected = f64x2::from([-7.0, -10.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_neg_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_neg_sub(self, m: Self, s: Self) -> Self {
     pick! {
         if #[cfg(all(target_feature="fma"))] {
-          Self { sse: fused_mul_neg_sub_m128d(self.sse, m.sse, a.sse) }
+          Self { sse: fused_mul_neg_sub_m128d(self.sse, m.sse, s.sse) }
+        } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))] {
+          unsafe { Self { neon: vnegq_f64(vfmaq_f64(s.neon, self.neon, m.neon)) } }
         } else {
-          -(self * m) - a
+          -(self * m) - s
         }
     }
   }
@@ -780,7 +890,7 @@ impl f64x2 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x2::splat(0.625));
+    let big = xa.simd_ge(f64x2::splat(0.625));
 
     let x1 = big.blend(f64x2::splat(1.0) - xa, xa * xa);
 
@@ -834,7 +944,7 @@ impl f64x2 {
     let asin = asin.flip_signs(self);
 
     // acos
-    let z3 = self.cmp_lt(f64x2::ZERO).blend(f64x2::PI - z1, z1);
+    let z3 = self.simd_lt(f64x2::ZERO).blend(f64x2::PI - z1, z1);
     let z4 = f64x2::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -871,7 +981,7 @@ impl f64x2 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x2::splat(0.625));
+    let big = xa.simd_ge(f64x2::splat(0.625));
 
     let x1 = big.blend(f64x2::splat(1.0) - xa, xa * xa);
 
@@ -920,7 +1030,7 @@ impl f64x2 {
     }
 
     // acos
-    let z3 = self.cmp_lt(f64x2::ZERO).blend(f64x2::PI - z1, z1);
+    let z3 = self.simd_lt(f64x2::ZERO).blend(f64x2::PI - z1, z1);
     let z4 = f64x2::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -957,7 +1067,7 @@ impl f64x2 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x2::splat(0.625));
+    let big = xa.simd_ge(f64x2::splat(0.625));
 
     let x1 = big.blend(f64x2::splat(1.0) - xa, xa * xa);
 
@@ -1038,8 +1148,8 @@ impl f64x2 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -1094,7 +1204,7 @@ impl f64x2 {
     // move in first octant
     let x1 = x.abs();
     let y1 = y.abs();
-    let swapxy = y1.cmp_gt(x1);
+    let swapxy = y1.simd_gt(x1);
     // swap x and y if y1 > x1
     let mut x2 = swapxy.blend(y1, x1);
     let mut y2 = swapxy.blend(x1, y1);
@@ -1113,8 +1223,8 @@ impl f64x2 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -1140,7 +1250,7 @@ impl f64x2 {
 
     // move back in place
     re = swapxy.blend(Self::FRAC_PI_2 - re, re);
-    re = ((x | y).cmp_eq(Self::ZERO)).blend(Self::ZERO, re);
+    re = ((x | y).simd_eq(Self::ZERO)).blend(Self::ZERO, re);
     re = (x.sign_bit()).blend(Self::PI - re, re);
 
     // get sign bit
@@ -1189,9 +1299,9 @@ impl f64x2 {
     c =
       (x2 * x2).mul_add(c, x2.mul_neg_add(f64x2::from(0.5), f64x2::from(1.0)));
 
-    let swap = !((q & i64x2::from(1)).cmp_eq(i64x2::from(0)));
+    let swap = !((q & i64x2::from(1)).simd_eq(i64x2::from(0)));
 
-    let mut overflow: f64x2 = cast(q.cmp_gt(i64x2::from(0x80000000000000)));
+    let mut overflow: f64x2 = cast(q.simd_gt(i64x2::from(0x80000000000000)));
     overflow &= xa.is_finite();
     s = overflow.blend(f64x2::from(0.0), s);
     c = overflow.blend(f64x2::from(1.0), c);
@@ -1263,22 +1373,22 @@ impl f64x2 {
   }
   #[inline]
   #[must_use]
-  pub fn move_mask(self) -> i32 {
+  pub fn to_bitmask(self) -> u32 {
     pick! {
       if #[cfg(target_feature="sse2")] {
-        move_mask_m128d(self.sse)
+        move_mask_m128d(self.sse) as u32
       } else if #[cfg(target_feature="simd128")] {
-        u64x2_bitmask(self.simd) as i32
+        u64x2_bitmask(self.simd) as u32
       } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))]{
         unsafe
         {
           let e = vreinterpretq_u64_f64(self.neon);
 
-          (vgetq_lane_u64(e,0) >> 63 | ((vgetq_lane_u64(e,1) >> 62) & 0x2)) as i32
+          (vgetq_lane_u64(e,0) >> 63 | ((vgetq_lane_u64(e,1) >> 62) & 0x2)) as u32
         }
       } else {
-        (((self.arr[0].to_bits() as i64) < 0) as i32) << 0 |
-        (((self.arr[1].to_bits() as i64) < 0) as i32) << 1
+        (((self.arr[0].to_bits() as i64) < 0) as u32) << 0 |
+        (((self.arr[1].to_bits() as i64) < 0) as u32) << 1
       }
     }
   }
@@ -1289,7 +1399,7 @@ impl f64x2 {
       if #[cfg(target_feature="simd128")] {
         v128_any_true(self.simd)
       } else {
-        self.move_mask() != 0
+        self.to_bitmask() != 0
       }
     }
   }
@@ -1301,7 +1411,7 @@ impl f64x2 {
         u64x2_all_true(self.simd)
       } else {
         // two lanes
-        self.move_mask() == 0b11
+        self.to_bitmask() == 0b11
       }
     }
   }
@@ -1347,7 +1457,7 @@ impl f64x2 {
     let n2 = Self::vm_pow2n(r);
     let z = (z + Self::ONE) * n2;
     // check for overflow
-    let in_range = self.abs().cmp_lt(max_x);
+    let in_range = self.abs().simd_lt(max_x);
     let in_range = in_range & self.is_finite();
     in_range.blend(z, Self::ZERO)
   }
@@ -1377,7 +1487,7 @@ impl f64x2 {
   fn is_zero_or_subnormal(self) -> Self {
     let t = cast::<_, i64x2>(self);
     let t = t & i64x2::splat(0x7FF0000000000000);
-    i64x2::round_float(t.cmp_eq(i64x2::splat(0)))
+    i64x2::round_float(t.simd_eq(i64x2::splat(0)))
   }
 
   #[inline]
@@ -1399,7 +1509,7 @@ impl f64x2 {
   fn sign_bit(self) -> Self {
     let t1 = cast::<_, i64x2>(self);
     let t2 = t1 >> 63;
-    !cast::<_, f64x2>(t2).cmp_eq(f64x2::ZERO)
+    !cast::<_, f64x2>(t2).simd_eq(f64x2::ZERO)
   }
 
   /// horizontal add of all the elements of the vector
@@ -1444,7 +1554,7 @@ impl f64x2 {
     let x1 = self;
     let x = Self::fraction_2(x1);
     let e = Self::exponent(x1);
-    let mask = x.cmp_gt(VM_SQRT2 * f64x2::HALF);
+    let mask = x.simd_gt(VM_SQRT2 * f64x2::HALF);
     let x = (!mask).blend(x + x, x);
     let fe = mask.blend(e + Self::ONE, e);
     let x = x - Self::ONE;
@@ -1457,7 +1567,7 @@ impl f64x2 {
     let res = res + x2.mul_neg_add(f64x2::HALF, x);
     let res = fe.mul_add(LN2F_HI, res);
     let overflow = !self.is_finite();
-    let underflow = x1.cmp_lt(VM_SMALLEST_NORMAL);
+    let underflow = x1.simd_lt(VM_SMALLEST_NORMAL);
     let mask = overflow | underflow;
     if !mask.any() {
       res
@@ -1516,7 +1626,7 @@ impl f64x2 {
 
     let x1 = self.abs();
     let x = x1.fraction_2();
-    let mask = x.cmp_gt(f64x2::SQRT_2 * f64x2::HALF);
+    let mask = x.simd_gt(f64x2::SQRT_2 * f64x2::HALF);
     let x = (!mask).blend(x + x, x);
     let x = x - f64x2::ONE;
     let x2 = x * x;
@@ -1549,10 +1659,10 @@ impl f64x2 {
     let ei = cast::<_, i64x2>(ee.round_int());
     let ej = cast::<_, i64x2>(ei + (cast::<_, i64x2>(z) >> 52));
 
-    let overflow = cast::<_, f64x2>(!ej.cmp_lt(i64x2::splat(0x07FF)))
-      | ee.cmp_gt(f64x2::splat(3000.0));
-    let underflow = cast::<_, f64x2>(!ej.cmp_gt(i64x2::splat(0x000)))
-      | ee.cmp_lt(f64x2::splat(-3000.0));
+    let overflow = cast::<_, f64x2>(!ej.simd_lt(i64x2::splat(0x07FF)))
+      | ee.simd_gt(f64x2::splat(3000.0));
+    let underflow = cast::<_, f64x2>(!ej.simd_gt(i64x2::splat(0x000)))
+      | ee.simd_lt(f64x2::splat(-3000.0));
 
     // Add exponent by integer addition
     let z = cast::<_, f64x2>(cast::<_, i64x2>(z) + (ei << 52));
@@ -1568,9 +1678,9 @@ impl f64x2 {
     // Check for self == 0
     let x_zero = self.is_zero_or_subnormal();
     let z = x_zero.blend(
-      y.cmp_lt(f64x2::ZERO).blend(
+      y.simd_lt(f64x2::ZERO).blend(
         Self::infinity(),
-        y.cmp_eq(f64x2::ZERO).blend(f64x2::ONE, f64x2::ZERO),
+        y.simd_eq(f64x2::ZERO).blend(f64x2::ONE, f64x2::ZERO),
       ),
       z,
     );
@@ -1578,12 +1688,12 @@ impl f64x2 {
     let x_sign = self.sign_bit();
     let z = if x_sign.any() {
       // Y into an integer
-      let yi = y.cmp_eq(y.round());
+      let yi = y.simd_eq(y.round());
       // Is y odd?
       let y_odd = cast::<_, i64x2>(y.round_int() << 63).round_float();
 
       let z1 =
-        yi.blend(z | y_odd, self.cmp_eq(Self::ZERO).blend(z, Self::nan_pow()));
+        yi.blend(z | y_odd, self.simd_eq(Self::ZERO).blend(z, Self::nan_pow()));
       x_sign.blend(z1, z)
     } else {
       z
@@ -1611,12 +1721,12 @@ impl f64x2 {
   }
 
   #[inline]
-  pub fn as_array_ref(&self) -> &[f64; 2] {
+  pub fn as_array(&self) -> &[f64; 2] {
     cast_ref(self)
   }
 
   #[inline]
-  pub fn as_array_mut(&mut self) -> &mut [f64; 2] {
+  pub fn as_mut_array(&mut self) -> &mut [f64; 2] {
     cast_mut(self)
   }
 
@@ -1633,8 +1743,8 @@ impl f64x2 {
         Self { neon: unsafe { vcvtq_f64_s64(vmovl_s32(vget_low_s32(v.neon))) }}
       } else {
         Self { arr: [
-            v.as_array_ref()[0] as f64,
-            v.as_array_ref()[1] as f64,
+            v.as_array()[0] as f64,
+            v.as_array()[1] as f64,
         ]}
       }
     }
