@@ -47,6 +47,10 @@ impl f64x4 {
 unsafe impl Zeroable for f64x4 {}
 unsafe impl Pod for f64x4 {}
 
+impl AlignTo for f64x4 {
+  type Elem = f64;
+}
+
 impl Add for f64x4 {
   type Output = Self;
   #[inline]
@@ -233,14 +237,14 @@ impl BitXor for f64x4 {
 impl CmpEq for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_eq(self, rhs: Self) -> Self::Output {
+  fn simd_eq(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!(EqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_eq(rhs.a),
-          b : self.b.cmp_eq(rhs.b),
+          a : self.a.simd_eq(rhs.a),
+          b : self.b.simd_eq(rhs.b),
         }
       }
     }
@@ -250,14 +254,14 @@ impl CmpEq for f64x4 {
 impl CmpGe for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_ge(self, rhs: Self) -> Self::Output {
+  fn simd_ge(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!(GreaterEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_ge(rhs.a),
-          b : self.b.cmp_ge(rhs.b),
+          a : self.a.simd_ge(rhs.a),
+          b : self.b.simd_ge(rhs.b),
         }
       }
     }
@@ -267,14 +271,14 @@ impl CmpGe for f64x4 {
 impl CmpGt for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_gt(self, rhs: Self) -> Self::Output {
+  fn simd_gt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!( GreaterThanOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_gt(rhs.a),
-          b : self.b.cmp_gt(rhs.b),
+          a : self.a.simd_gt(rhs.a),
+          b : self.b.simd_gt(rhs.b),
         }
       }
     }
@@ -284,14 +288,14 @@ impl CmpGt for f64x4 {
 impl CmpNe for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_ne(self, rhs: Self) -> Self::Output {
+  fn simd_ne(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!(NotEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_ne(rhs.a),
-          b : self.b.cmp_ne(rhs.b),
+          a : self.a.simd_ne(rhs.a),
+          b : self.b.simd_ne(rhs.b),
         }
       }
     }
@@ -301,14 +305,14 @@ impl CmpNe for f64x4 {
 impl CmpLe for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_le(self, rhs: Self) -> Self::Output {
+  fn simd_le(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!(LessEqualOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_le(rhs.a),
-          b : self.b.cmp_le(rhs.b),
+          a : self.a.simd_le(rhs.a),
+          b : self.b.simd_le(rhs.b),
         }
       }
     }
@@ -318,14 +322,14 @@ impl CmpLe for f64x4 {
 impl CmpLt for f64x4 {
   type Output = Self;
   #[inline]
-  fn cmp_lt(self, rhs: Self) -> Self::Output {
+  fn simd_lt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx")]{
         Self { avx: cmp_op_mask_m256d::<{cmp_op!(LessThanOrdered)}>(self.avx, rhs.avx) }
       } else {
         Self {
-          a : self.a.cmp_lt(rhs.a),
-          b : self.b.cmp_lt(rhs.b),
+          a : self.a.simd_lt(rhs.a),
+          b : self.b.simd_lt(rhs.b),
         }
       }
     }
@@ -497,7 +501,7 @@ impl f64x4 {
     let shifted_exp_mask = u64x4::from(0xFFE0000000000000);
     let u: u64x4 = cast(self);
     let shift_u = u << 1_u64;
-    let out = !(shift_u & shifted_exp_mask).cmp_eq(shifted_exp_mask);
+    let out = !(shift_u & shifted_exp_mask).simd_eq(shifted_exp_mask);
     cast(out)
   }
 
@@ -507,7 +511,7 @@ impl f64x4 {
     let shifted_inf = u64x4::from(0xFFE0000000000000);
     let u: u64x4 = cast(self);
     let shift_u = u << 1_u64;
-    let out = (shift_u).cmp_eq(shifted_inf);
+    let out = (shift_u).simd_eq(shifted_inf);
     cast(out)
   }
 
@@ -539,6 +543,30 @@ impl f64x4 {
     ])
   }
 
+  /// Performs a multiply-add operation: `self * m + a`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and add operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses 256-bit `vfmadd` (single rounding,
+  ///   best accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `(self * m) + a` (two roundings)
+  /// - Other platforms: Delegates to [`f64x2`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x4;
+  /// let a = f64x4::from([1.0, 2.0, 3.0, 4.0]);
+  /// let b = f64x4::from([2.0; 4]);
+  /// let c = f64x4::from([10.0; 4]);
+  ///
+  /// let result = a.mul_add(b, c);
+  ///
+  /// let expected = f64x4::from([12.0, 14.0, 16.0, 18.0]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_add(self, m: Self, a: Self) -> Self {
@@ -557,24 +585,72 @@ impl f64x4 {
     }
   }
 
+  /// Performs a multiply-subtract operation: `self * m - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and subtract operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses 256-bit `vfmsub` (single rounding,
+  ///   best accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `(self * m) - s` (two roundings)
+  /// - Other platforms: Delegates to [`f64x2`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x4;
+  /// let a = f64x4::from([10.0; 4]);
+  /// let b = f64x4::from([2.0; 4]);
+  /// let c = f64x4::from([5.0; 4]);
+  ///
+  /// let result = a.mul_sub(b, c);
+  ///
+  /// let expected = f64x4::from([15.0; 4]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_sub(self, m: Self, s: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="avx",target_feature="fma"))] {
-        Self { avx: fused_mul_sub_m256d(self.avx, m.avx, a.avx) }
+        Self { avx: fused_mul_sub_m256d(self.avx, m.avx, s.avx) }
       } else if #[cfg(target_feature="avx")] {
         // still want to use 256 bit ops
-        (self * m) - a
+        (self * m) - s
       } else {
         Self {
-          a : self.a.mul_sub(m.a, a.a),
-          b : self.b.mul_sub(m.b, a.b),
+          a : self.a.mul_sub(m.a, s.a),
+          b : self.b.mul_sub(m.b, s.b),
         }
       }
     }
   }
 
+  /// Performs a negative multiply-add operation: `a - (self * m)`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses 256-bit `vfnmadd` (single rounding,
+  ///   best accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `a - (self * m)` (two roundings)
+  /// - Other platforms: Delegates to [`f64x2`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x4;
+  /// let a = f64x4::from([3.0; 4]);
+  /// let b = f64x4::from([2.0; 4]);
+  /// let c = f64x4::from([10.0; 4]);
+  ///
+  /// let result = a.mul_neg_add(b, c);
+  ///
+  /// let expected = f64x4::from([4.0; 4]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_neg_add(self, m: Self, a: Self) -> Self {
@@ -593,19 +669,43 @@ impl f64x4 {
     }
   }
 
+  /// Performs a negative multiply-subtract operation: `-(self * m) - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX+FMA: Uses 256-bit `vfnmsub` (single rounding,
+  ///   best accuracy)
+  /// - On `x86`/`x86_64` with AVX only: Uses `-(self * m) - s` (two roundings)
+  /// - Other platforms: Delegates to [`f64x2`] (may use NEON FMA or fallback)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x4;
+  /// let a = f64x4::from([3.0; 4]);
+  /// let b = f64x4::from([2.0; 4]);
+  /// let c = f64x4::from([1.0; 4]);
+  ///
+  /// let result = a.mul_neg_sub(b, c);
+  ///
+  /// let expected = f64x4::from([-7.0; 4]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_neg_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_neg_sub(self, m: Self, s: Self) -> Self {
     pick! {
        if #[cfg(all(target_feature="avx",target_feature="fma"))] {
-         Self { avx: fused_mul_neg_sub_m256d(self.avx, m.avx, a.avx) }
+         Self { avx: fused_mul_neg_sub_m256d(self.avx, m.avx, s.avx) }
         } else if #[cfg(target_feature="avx")] {
           // still want to use 256 bit ops
-          -(self * m) - a
+          -(self * m) - s
         } else {
          Self {
-           a : self.a.mul_neg_sub(m.a, a.a),
-           b : self.b.mul_neg_sub(m.b, a.b),
+           a : self.a.mul_neg_sub(m.a, s.a),
+           b : self.b.mul_neg_sub(m.b, s.b),
          }
        }
     }
@@ -654,7 +754,7 @@ impl f64x4 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x4::splat(0.625));
+    let big = xa.simd_ge(f64x4::splat(0.625));
 
     let x1 = big.blend(f64x4::splat(1.0) - xa, xa * xa);
 
@@ -709,7 +809,7 @@ impl f64x4 {
     let asin = asin.flip_signs(self);
 
     // acos
-    let z3 = self.cmp_lt(f64x4::ZERO).blend(f64x4::PI - z1, z1);
+    let z3 = self.simd_lt(f64x4::ZERO).blend(f64x4::PI - z1, z1);
     let z4 = f64x4::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -746,7 +846,7 @@ impl f64x4 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x4::splat(0.625));
+    let big = xa.simd_ge(f64x4::splat(0.625));
 
     let x1 = big.blend(f64x4::splat(1.0) - xa, xa * xa);
 
@@ -795,7 +895,7 @@ impl f64x4 {
     }
 
     // acos
-    let z3 = self.cmp_lt(f64x4::ZERO).blend(f64x4::PI - z1, z1);
+    let z3 = self.simd_lt(f64x4::ZERO).blend(f64x4::PI - z1, z1);
     let z4 = f64x4::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -832,7 +932,7 @@ impl f64x4 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x4::splat(0.625));
+    let big = xa.simd_ge(f64x4::splat(0.625));
 
     let x1 = big.blend(f64x4::splat(1.0) - xa, xa * xa);
 
@@ -913,8 +1013,8 @@ impl f64x4 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -969,7 +1069,7 @@ impl f64x4 {
     // move in first octant
     let x1 = x.abs();
     let y1 = y.abs();
-    let swapxy = y1.cmp_gt(x1);
+    let swapxy = y1.simd_gt(x1);
     // swap x and y if y1 > x1
     let mut x2 = swapxy.blend(y1, x1);
     let mut y2 = swapxy.blend(x1, y1);
@@ -988,8 +1088,8 @@ impl f64x4 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -1015,7 +1115,7 @@ impl f64x4 {
 
     // move back in place
     re = swapxy.blend(Self::FRAC_PI_2 - re, re);
-    re = ((x | y).cmp_eq(Self::ZERO)).blend(Self::ZERO, re);
+    re = ((x | y).simd_eq(Self::ZERO)).blend(Self::ZERO, re);
     re = (x.sign_bit()).blend(Self::PI - re, re);
 
     // get sign bit
@@ -1064,9 +1164,9 @@ impl f64x4 {
     c =
       (x2 * x2).mul_add(c, x2.mul_neg_add(f64x4::from(0.5), f64x4::from(1.0)));
 
-    let swap = !((q & i64x4::from(1)).cmp_eq(i64x4::from(0)));
+    let swap = !((q & i64x4::from(1)).simd_eq(i64x4::from(0)));
 
-    let mut overflow: f64x4 = cast(q.cmp_gt(i64x4::from(0x80000000000000)));
+    let mut overflow: f64x4 = cast(q.simd_gt(i64x4::from(0x80000000000000)));
     overflow &= xa.is_finite();
     s = overflow.blend(f64x4::from(0.0), s);
     c = overflow.blend(f64x4::from(1.0), c);
@@ -1129,12 +1229,12 @@ impl f64x4 {
   }
   #[inline]
   #[must_use]
-  pub fn move_mask(self) -> i32 {
+  pub fn to_bitmask(self) -> u32 {
     pick! {
       if #[cfg(target_feature="avx")] {
-        move_mask_m256d(self.avx)
+        move_mask_m256d(self.avx) as u32
       } else {
-        (self.b.move_mask() << 2) | self.a.move_mask()
+        (self.b.to_bitmask() << 2) | self.a.to_bitmask()
       }
     }
   }
@@ -1202,7 +1302,7 @@ impl f64x4 {
     let n2 = Self::vm_pow2n(r);
     let z = (z + Self::ONE) * n2;
     // check for overflow
-    let in_range = self.abs().cmp_lt(max_x);
+    let in_range = self.abs().simd_lt(max_x);
     let in_range = in_range & self.is_finite();
     in_range.blend(z, Self::ZERO)
   }
@@ -1231,7 +1331,7 @@ impl f64x4 {
   fn is_zero_or_subnormal(self) -> Self {
     let t = cast::<_, i64x4>(self);
     let t = t & i64x4::splat(0x7FF0000000000000);
-    i64x4::round_float(t.cmp_eq(i64x4::splat(0)))
+    i64x4::round_float(t.simd_eq(i64x4::splat(0)))
   }
   #[inline]
   fn infinity() -> Self {
@@ -1249,7 +1349,7 @@ impl f64x4 {
   fn sign_bit(self) -> Self {
     let t1 = cast::<_, i64x4>(self);
     let t2 = t1 >> 63;
-    !cast::<_, f64x4>(t2).cmp_eq(f64x4::ZERO)
+    !cast::<_, f64x4>(t2).simd_eq(f64x4::ZERO)
   }
 
   /// horizontal add of all the elements of the vector
@@ -1295,7 +1395,7 @@ impl f64x4 {
     let x1 = self;
     let x = Self::fraction_2(x1);
     let e = Self::exponent(x1);
-    let mask = x.cmp_gt(VM_SQRT2 * HALF);
+    let mask = x.simd_gt(VM_SQRT2 * HALF);
     let x = (!mask).blend(x + x, x);
     let fe = mask.blend(e + Self::ONE, e);
     let x = x - Self::ONE;
@@ -1308,7 +1408,7 @@ impl f64x4 {
     let res = res + x2.mul_neg_add(HALF, x);
     let res = fe.mul_add(LN2F_HI, res);
     let overflow = !self.is_finite();
-    let underflow = x1.cmp_lt(VM_SMALLEST_NORMAL);
+    let underflow = x1.simd_lt(VM_SMALLEST_NORMAL);
     let mask = overflow | underflow;
     if !mask.any() {
       res
@@ -1367,7 +1467,7 @@ impl f64x4 {
 
     let x1 = self.abs();
     let x = x1.fraction_2();
-    let mask = x.cmp_gt(f64x4::SQRT_2 * f64x4::HALF);
+    let mask = x.simd_gt(f64x4::SQRT_2 * f64x4::HALF);
     let x = (!mask).blend(x + x, x);
     let x = x - f64x4::ONE;
     let x2 = x * x;
@@ -1400,10 +1500,10 @@ impl f64x4 {
     let ei = cast::<_, i64x4>(ee.round_int());
     let ej = cast::<_, i64x4>(ei + (cast::<_, i64x4>(z) >> 52));
 
-    let overflow = cast::<_, f64x4>(!ej.cmp_lt(i64x4::splat(0x07FF)))
-      | ee.cmp_gt(f64x4::splat(3000.0));
-    let underflow = cast::<_, f64x4>(!ej.cmp_gt(i64x4::splat(0x000)))
-      | ee.cmp_lt(f64x4::splat(-3000.0));
+    let overflow = cast::<_, f64x4>(!ej.simd_lt(i64x4::splat(0x07FF)))
+      | ee.simd_gt(f64x4::splat(3000.0));
+    let underflow = cast::<_, f64x4>(!ej.simd_gt(i64x4::splat(0x000)))
+      | ee.simd_lt(f64x4::splat(-3000.0));
 
     // Add exponent by integer addition
     let z = cast::<_, f64x4>(cast::<_, i64x4>(z) + (ei << 52));
@@ -1419,9 +1519,9 @@ impl f64x4 {
     // Check for self == 0
     let x_zero = self.is_zero_or_subnormal();
     let z = x_zero.blend(
-      y.cmp_lt(f64x4::ZERO).blend(
+      y.simd_lt(f64x4::ZERO).blend(
         Self::infinity(),
-        y.cmp_eq(f64x4::ZERO).blend(f64x4::ONE, f64x4::ZERO),
+        y.simd_eq(f64x4::ZERO).blend(f64x4::ONE, f64x4::ZERO),
       ),
       z,
     );
@@ -1430,11 +1530,11 @@ impl f64x4 {
 
     let z = if x_sign.any() {
       // Y into an integer
-      let yi = y.cmp_eq(y.round());
+      let yi = y.simd_eq(y.round());
       // Is y odd?
       let y_odd = cast::<_, i64x4>(y.round_int() << 63).round_float();
       let z1 =
-        yi.blend(z | y_odd, self.cmp_eq(Self::ZERO).blend(z, Self::nan_pow()));
+        yi.blend(z | y_odd, self.simd_eq(Self::ZERO).blend(z, Self::nan_pow()));
       x_sign.blend(z1, z)
     } else {
       z
@@ -1461,12 +1561,12 @@ impl f64x4 {
   }
 
   #[inline]
-  pub fn as_array_ref(&self) -> &[f64; 4] {
+  pub fn as_array(&self) -> &[f64; 4] {
     cast_ref(self)
   }
 
   #[inline]
-  pub fn as_array_mut(&mut self) -> &mut [f64; 4] {
+  pub fn as_mut_array(&mut self) -> &mut [f64; 4] {
     cast_mut(self)
   }
 
@@ -1477,10 +1577,10 @@ impl f64x4 {
         Self { avx: convert_to_m256d_from_i32_m128i(v.sse) }
       } else {
         Self::new([
-          v.as_array_ref()[0] as f64,
-          v.as_array_ref()[1] as f64,
-          v.as_array_ref()[2] as f64,
-          v.as_array_ref()[3] as f64,
+          v.as_array()[0] as f64,
+          v.as_array()[1] as f64,
+          v.as_array()[2] as f64,
+          v.as_array()[3] as f64,
         ])
       }
     }
