@@ -22,6 +22,10 @@ macro_rules! const_f64_as_f64x8 {
 unsafe impl Zeroable for f64x8 {}
 unsafe impl Pod for f64x8 {}
 
+impl AlignTo for f64x8 {
+  type Elem = f64;
+}
+
 impl Add for f64x8 {
   type Output = Self;
   #[inline]
@@ -202,14 +206,14 @@ impl BitXor for f64x8 {
 impl CmpEq for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_eq(self, rhs: Self) -> Self::Output {
+  fn simd_eq(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(EqualOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_eq(rhs.a),
-          b : self.b.cmp_eq(rhs.b),
+          a : self.a.simd_eq(rhs.a),
+          b : self.b.simd_eq(rhs.b),
         }
       }
     }
@@ -219,14 +223,14 @@ impl CmpEq for f64x8 {
 impl CmpGt for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_gt(self, rhs: Self) -> Self::Output {
+  fn simd_gt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(GreaterThanOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_gt(rhs.a),
-          b : self.b.cmp_gt(rhs.b),
+          a : self.a.simd_gt(rhs.a),
+          b : self.b.simd_gt(rhs.b),
         }
       }
     }
@@ -236,14 +240,14 @@ impl CmpGt for f64x8 {
 impl CmpGe for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_ge(self, rhs: Self) -> Self::Output {
+  fn simd_ge(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(GreaterEqualOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_ge(rhs.a),
-          b : self.b.cmp_ge(rhs.b),
+          a : self.a.simd_ge(rhs.a),
+          b : self.b.simd_ge(rhs.b),
         }
       }
     }
@@ -253,14 +257,14 @@ impl CmpGe for f64x8 {
 impl CmpLt for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_lt(self, rhs: Self) -> Self::Output {
+  fn simd_lt(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(LessThanOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_lt(rhs.a),
-          b : self.b.cmp_lt(rhs.b),
+          a : self.a.simd_lt(rhs.a),
+          b : self.b.simd_lt(rhs.b),
         }
       }
     }
@@ -270,14 +274,14 @@ impl CmpLt for f64x8 {
 impl CmpLe for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_le(self, rhs: Self) -> Self::Output {
+  fn simd_le(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(LessEqualOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_le(rhs.a),
-          b : self.b.cmp_le(rhs.b),
+          a : self.a.simd_le(rhs.a),
+          b : self.b.simd_le(rhs.b),
         }
       }
     }
@@ -287,14 +291,14 @@ impl CmpLe for f64x8 {
 impl CmpNe for f64x8 {
   type Output = Self;
   #[inline]
-  fn cmp_ne(self, rhs: Self) -> Self::Output {
+  fn simd_ne(self, rhs: Self) -> Self::Output {
     pick! {
       if #[cfg(target_feature="avx512f")] {
         Self { avx512: cmp_op_mask_m512d::<{cmp_op!(NotEqualOrdered)}>(self.avx512, rhs.avx512) }
       } else {
         Self {
-          a : self.a.cmp_ne(rhs.a),
-          b : self.b.cmp_ne(rhs.b),
+          a : self.a.simd_ne(rhs.a),
+          b : self.b.simd_ne(rhs.b),
         }
       }
     }
@@ -330,7 +334,7 @@ impl f64x8 {
   pub const fn new(array: [f64; 8]) -> Self {
     unsafe { core::mem::transmute(array) }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn blend(self, t: Self, f: Self) -> Self {
@@ -345,7 +349,7 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn abs(self) -> Self {
@@ -361,7 +365,7 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn floor(self) -> Self {
@@ -420,7 +424,7 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn fast_min(self, rhs: Self) -> Self {
@@ -450,7 +454,7 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn is_nan(self) -> Self {
@@ -465,24 +469,24 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn is_finite(self) -> Self {
     let shifted_exp_mask = u64x8::splat(0xFFE0000000000000);
     let u: u64x8 = cast(self);
     let shift_u = u << 1_u64;
-    let out = !(shift_u & shifted_exp_mask).cmp_eq(shifted_exp_mask);
+    let out = !(shift_u & shifted_exp_mask).simd_eq(shifted_exp_mask);
     cast(out)
   }
-  
+
   #[inline]
   #[must_use]
   pub fn is_inf(self) -> Self {
     let shifted_inf = u64x8::from(0xFFE0000000000000);
     let u: u64x8 = cast(self);
     let shift_u = u << 1_u64;
-    let out = (shift_u).cmp_eq(shifted_inf);
+    let out = (shift_u).simd_eq(shifted_inf);
     cast(out)
   }
 
@@ -500,7 +504,7 @@ impl f64x8 {
       }
     }
   }
-  
+
   #[inline]
   #[must_use]
   pub fn round_int(self) -> i64x8 {
@@ -516,7 +520,32 @@ impl f64x8 {
       rounded[7] as i64,
     ])
   }
-  
+
+  /// Performs a multiply-add operation: `self * m + a`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and add operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX-512F+FMA: Uses 512-bit `vfmadd` (single
+  ///   rounding, best accuracy)
+  /// - On `x86`/`x86_64` with AVX-512F only: Uses `(self * m) + a` (two
+  ///   roundings)
+  /// - Other platforms: Delegates to [`f64x4`] (inherits its FMA behavior)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x8;
+  /// let a = f64x8::from([1.0; 8]);
+  /// let b = f64x8::from([2.0; 8]);
+  /// let c = f64x8::from([10.0; 8]);
+  ///
+  /// let result = a.mul_add(b, c);
+  ///
+  /// let expected = f64x8::from([12.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_add(self, m: Self, a: Self) -> Self {
@@ -535,24 +564,74 @@ impl f64x8 {
     }
   }
 
+  /// Performs a multiply-subtract operation: `self * m - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// multiply and subtract operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX-512F+FMA: Uses 512-bit `vfmsub` (single
+  ///   rounding, best accuracy)
+  /// - On `x86`/`x86_64` with AVX-512F only: Uses `(self * m) - s` (two
+  ///   roundings)
+  /// - Other platforms: Delegates to [`f64x4`] (inherits its FMA behavior)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x8;
+  /// let a = f64x8::from([10.0; 8]);
+  /// let b = f64x8::from([3.0; 8]);
+  /// let c = f64x8::from([5.0; 8]);
+  ///
+  /// let result = a.mul_sub(b, c);
+  ///
+  /// let expected = f64x8::from([25.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_sub(self, m: Self, s: Self) -> Self {
     pick! {
       if #[cfg(all(target_feature="avx512f",target_feature="fma"))] {
-        Self { avx512: fused_mul_sub_m512d(self.avx512, m.avx512, a.avx512) }
+        Self { avx512: fused_mul_sub_m512d(self.avx512, m.avx512, s.avx512) }
       } else if #[cfg(target_feature="avx512f")] {
         // still want to use 512 bit ops
-        (self * m) - a
+        (self * m) - s
       } else {
         Self {
-          a : self.a.mul_sub(m.a, a.a),
-          b : self.b.mul_sub(m.b, a.b),
+          a : self.a.mul_sub(m.a, s.a),
+          b : self.b.mul_sub(m.b, s.b),
         }
       }
     }
   }
 
+  /// Performs a negative multiply-add operation: `a - (self * m)`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX-512F+FMA: Uses 512-bit `vfnmadd` (single
+  ///   rounding, best accuracy)
+  /// - On `x86`/`x86_64` with AVX-512F only: Uses `a - (self * m)` (two
+  ///   roundings)
+  /// - Other platforms: Delegates to [`f64x4`] (inherits its FMA behavior)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x8;
+  /// let a = f64x8::from([4.0; 8]);
+  /// let b = f64x8::from([2.0; 8]);
+  /// let c = f64x8::from([10.0; 8]);
+  ///
+  /// let result = a.mul_neg_add(b, c);
+  ///
+  /// let expected = f64x8::from([2.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
   pub fn mul_neg_add(self, m: Self, a: Self) -> Self {
@@ -571,19 +650,44 @@ impl f64x8 {
     }
   }
 
+  /// Performs a negative multiply-subtract operation: `-(self * m) - s`
+  ///
+  /// When hardware FMA support is available, this computes the result with a
+  /// single rounding operation. Without FMA support, it falls back to separate
+  /// operations with two roundings.
+  ///
+  /// # Platform-specific behavior
+  /// - On `x86`/`x86_64` with AVX-512F+FMA: Uses 512-bit `vfnmsub` (single
+  ///   rounding, best accuracy)
+  /// - On `x86`/`x86_64` with AVX-512F only: Uses `-(self * m) - s` (two
+  ///   roundings)
+  /// - Other platforms: Delegates to [`f64x4`] (inherits its FMA behavior)
+  ///
+  /// # Examples
+  /// ```
+  /// # use wide::f64x8;
+  /// let a = f64x8::from([4.0; 8]);
+  /// let b = f64x8::from([2.0; 8]);
+  /// let c = f64x8::from([1.0; 8]);
+  ///
+  /// let result = a.mul_neg_sub(b, c);
+  ///
+  /// let expected = f64x8::from([-9.0; 8]);
+  /// assert_eq!(result, expected);
+  /// ```
   #[inline]
   #[must_use]
-  pub fn mul_neg_sub(self, m: Self, a: Self) -> Self {
+  pub fn mul_neg_sub(self, m: Self, s: Self) -> Self {
     pick! {
        if #[cfg(all(target_feature="avx512f",target_feature="fma"))] {
-         Self { avx512: fused_mul_neg_sub_m512d(self.avx512, m.avx512, a.avx512) }
+         Self { avx512: fused_mul_neg_sub_m512d(self.avx512, m.avx512, s.avx512) }
         } else if #[cfg(target_feature="avx512f")] {
           // still want to use 512 bit ops
-          -(self * m) - a
+          -(self * m) - s
         } else {
          Self {
-           a : self.a.mul_neg_sub(m.a, a.a),
-           b : self.b.mul_neg_sub(m.b, a.b),
+           a : self.a.mul_neg_sub(m.a, s.a),
+           b : self.b.mul_neg_sub(m.b, s.b),
          }
        }
     }
@@ -632,7 +736,7 @@ impl f64x8 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x8::splat(0.625));
+    let big = xa.simd_ge(f64x8::splat(0.625));
 
     let x1 = big.blend(f64x8::splat(1.0) - xa, xa * xa);
 
@@ -687,7 +791,7 @@ impl f64x8 {
     let asin = asin.flip_signs(self);
 
     // acos
-    let z3 = self.cmp_lt(f64x8::ZERO).blend(f64x8::PI - z1, z1);
+    let z3 = self.simd_lt(f64x8::ZERO).blend(f64x8::PI - z1, z1);
     let z4 = f64x8::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -724,7 +828,7 @@ impl f64x8 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x8::splat(0.625));
+    let big = xa.simd_ge(f64x8::splat(0.625));
 
     let x1 = big.blend(f64x8::splat(1.0) - xa, xa * xa);
 
@@ -773,7 +877,7 @@ impl f64x8 {
     }
 
     // acos
-    let z3 = self.cmp_lt(f64x8::ZERO).blend(f64x8::PI - z1, z1);
+    let z3 = self.simd_lt(f64x8::ZERO).blend(f64x8::PI - z1, z1);
     let z4 = f64x8::FRAC_PI_2 - z2.flip_signs(self);
     let acos = big.blend(z3, z4);
 
@@ -810,7 +914,7 @@ impl f64x8 {
 
     let xa = self.abs();
 
-    let big = xa.cmp_ge(f64x8::splat(0.625));
+    let big = xa.simd_ge(f64x8::splat(0.625));
 
     let x1 = big.blend(f64x8::splat(1.0) - xa, xa * xa);
 
@@ -891,8 +995,8 @@ impl f64x8 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -947,7 +1051,7 @@ impl f64x8 {
     // move in first octant
     let x1 = x.abs();
     let y1 = y.abs();
-    let swapxy = y1.cmp_gt(x1);
+    let swapxy = y1.simd_gt(x1);
     // swap x and y if y1 > x1
     let mut x2 = swapxy.blend(y1, x1);
     let mut y2 = swapxy.blend(x1, y1);
@@ -966,8 +1070,8 @@ impl f64x8 {
     // small:  t < 0.66
     // medium: t <= t <= 2.4142 (1+sqrt(2))
     // big:    t > 2.4142
-    let notbig = t.cmp_le(T3PO8);
-    let notsmal = t.cmp_ge(Self::splat(0.66));
+    let notbig = t.simd_le(T3PO8);
+    let notsmal = t.simd_ge(Self::splat(0.66));
 
     let mut s = notbig.blend(Self::FRAC_PI_4, Self::FRAC_PI_2);
     s = notsmal & s;
@@ -993,7 +1097,7 @@ impl f64x8 {
 
     // move back in place
     re = swapxy.blend(Self::FRAC_PI_2 - re, re);
-    re = ((x | y).cmp_eq(Self::ZERO)).blend(Self::ZERO, re);
+    re = ((x | y).simd_eq(Self::ZERO)).blend(Self::ZERO, re);
     re = (x.sign_bit()).blend(Self::PI - re, re);
 
     // get sign bit
@@ -1042,9 +1146,9 @@ impl f64x8 {
     c =
       (x2 * x2).mul_add(c, x2.mul_neg_add(f64x8::from(0.5), f64x8::from(1.0)));
 
-    let swap = !((q & i64x8::from(1)).cmp_eq(i64x8::from(0)));
+    let swap = !((q & i64x8::from(1)).simd_eq(i64x8::from(0)));
 
-    let mut overflow: f64x8 = cast(q.cmp_gt(i64x8::from(0x80000000000000)));
+    let mut overflow: f64x8 = cast(q.simd_gt(i64x8::from(0x80000000000000)));
     overflow &= xa.is_finite();
     s = overflow.blend(f64x8::from(0.0), s);
     c = overflow.blend(f64x8::from(1.0), c);
@@ -1107,12 +1211,12 @@ impl f64x8 {
   }
   #[inline]
   #[must_use]
-  pub fn move_mask(self) -> i32 {
+  pub fn to_bitmask(self) -> u32 {
     pick! {
       if #[cfg(target_feature="avx512f")] {
-        movepi64_mask_m512d(self.avx512) as i32
+        movepi64_mask_m512d(self.avx512) as u32
       } else {
-        (self.b.move_mask() << 4) | self.a.move_mask()
+        (self.b.to_bitmask() << 4) | self.a.to_bitmask()
       }
     }
   }
@@ -1181,7 +1285,7 @@ impl f64x8 {
     let n2 = Self::vm_pow2n(r);
     let z = (z + Self::ONE) * n2;
     // check for overflow
-    let in_range = self.abs().cmp_lt(max_x);
+    let in_range = self.abs().simd_lt(max_x);
     let in_range = in_range & self.is_finite();
     in_range.blend(z, Self::ZERO)
   }
@@ -1210,7 +1314,7 @@ impl f64x8 {
   fn is_zero_or_subnormal(self) -> Self {
     let t = cast::<_, i64x8>(self);
     let t = t & i64x8::splat(0x7FF0000000000000);
-    i64x8::round_float(t.cmp_eq(i64x8::splat(0)))
+    i64x8::round_float(t.simd_eq(i64x8::splat(0)))
   }
   #[inline]
   fn infinity() -> Self {
@@ -1228,7 +1332,7 @@ impl f64x8 {
   fn sign_bit(self) -> Self {
     let t1 = cast::<_, i64x8>(self);
     let t2 = t1 >> 63;
-    !cast::<_, f64x8>(t2).cmp_eq(f64x8::ZERO)
+    !cast::<_, f64x8>(t2).simd_eq(f64x8::ZERO)
   }
 
   #[inline]
@@ -1275,7 +1379,7 @@ impl f64x8 {
     let x1 = self;
     let x = Self::fraction_2(x1);
     let e = Self::exponent(x1);
-    let mask = x.cmp_gt(VM_SQRT2 * HALF);
+    let mask = x.simd_gt(VM_SQRT2 * HALF);
     let x = (!mask).blend(x + x, x);
     let fe = mask.blend(e + Self::ONE, e);
     let x = x - Self::ONE;
@@ -1288,7 +1392,7 @@ impl f64x8 {
     let res = res + x2.mul_neg_add(HALF, x);
     let res = fe.mul_add(LN2F_HI, res);
     let overflow = !self.is_finite();
-    let underflow = x1.cmp_lt(VM_SMALLEST_NORMAL);
+    let underflow = x1.simd_lt(VM_SMALLEST_NORMAL);
     let mask = overflow | underflow;
     if !mask.any() {
       res
@@ -1347,7 +1451,7 @@ impl f64x8 {
 
     let x1 = self.abs();
     let x = x1.fraction_2();
-    let mask = x.cmp_gt(f64x8::SQRT_2 * f64x8::HALF);
+    let mask = x.simd_gt(f64x8::SQRT_2 * f64x8::HALF);
     let x = (!mask).blend(x + x, x);
     let x = x - f64x8::ONE;
     let x2 = x * x;
@@ -1380,10 +1484,10 @@ impl f64x8 {
     let ei = cast::<_, i64x8>(ee.round_int());
     let ej = cast::<_, i64x8>(ei + (cast::<_, i64x8>(z) >> 52));
 
-    let overflow = cast::<_, f64x8>(!ej.cmp_lt(i64x8::splat(0x07FF)))
-      | ee.cmp_gt(f64x8::splat(3000.0));
-    let underflow = cast::<_, f64x8>(!ej.cmp_gt(i64x8::splat(0x000)))
-      | ee.cmp_lt(f64x8::splat(-3000.0));
+    let overflow = cast::<_, f64x8>(!ej.simd_lt(i64x8::splat(0x07FF)))
+      | ee.simd_gt(f64x8::splat(3000.0));
+    let underflow = cast::<_, f64x8>(!ej.simd_gt(i64x8::splat(0x000)))
+      | ee.simd_lt(f64x8::splat(-3000.0));
 
     // Add exponent by integer addition
     let z = cast::<_, f64x8>(cast::<_, i64x8>(z) + (ei << 52));
@@ -1399,9 +1503,9 @@ impl f64x8 {
     // Check for self == 0
     let x_zero = self.is_zero_or_subnormal();
     let z = x_zero.blend(
-      y.cmp_lt(f64x8::ZERO).blend(
+      y.simd_lt(f64x8::ZERO).blend(
         Self::infinity(),
-        y.cmp_eq(f64x8::ZERO).blend(f64x8::ONE, f64x8::ZERO),
+        y.simd_eq(f64x8::ZERO).blend(f64x8::ONE, f64x8::ZERO),
       ),
       z,
     );
@@ -1410,11 +1514,11 @@ impl f64x8 {
 
     let z = if x_sign.any() {
       // Y into an integer
-      let yi = y.cmp_eq(y.round());
+      let yi = y.simd_eq(y.round());
       // Is y odd?
       let y_odd = cast::<_, i64x8>(y.round_int() << 63).round_float();
       let z1 =
-        yi.blend(z | y_odd, self.cmp_eq(Self::ZERO).blend(z, Self::nan_pow()));
+        yi.blend(z | y_odd, self.simd_eq(Self::ZERO).blend(z, Self::nan_pow()));
       x_sign.blend(z1, z)
     } else {
       z
@@ -1441,16 +1545,16 @@ impl f64x8 {
   pub fn to_array(self) -> [f64; 8] {
     cast(self)
   }
-  
+
   #[inline]
   #[must_use]
-  pub fn as_array_ref(&self) -> &[f64; 8] {
+  pub fn as_array(&self) -> &[f64; 8] {
     cast_ref(self)
   }
-  
+
   #[inline]
   #[must_use]
-  pub fn as_array_mut(&mut self) -> &mut [f64; 8] {
+  pub fn as_mut_array(&mut self) -> &mut [f64; 8] {
     cast_mut(self)
   }
 
@@ -1461,14 +1565,14 @@ impl f64x8 {
         Self { avx512: convert_to_m512d_from_i32_m256i(v.avx2) }
       } else {
         Self::new([
-          v.as_array_ref()[0] as f64,
-          v.as_array_ref()[1] as f64,
-          v.as_array_ref()[2] as f64,
-          v.as_array_ref()[3] as f64,
-          v.as_array_ref()[4] as f64,
-          v.as_array_ref()[5] as f64,
-          v.as_array_ref()[6] as f64,
-          v.as_array_ref()[7] as f64,
+          v.as_array()[0] as f64,
+          v.as_array()[1] as f64,
+          v.as_array()[2] as f64,
+          v.as_array()[3] as f64,
+          v.as_array()[4] as f64,
+          v.as_array()[5] as f64,
+          v.as_array()[6] as f64,
+          v.as_array()[7] as f64,
         ])
       }
     }
@@ -1497,4 +1601,4 @@ impl Not for f64x8 {
       }
     }
   }
-}
\ No newline at end of file
+}
