@@ -58,6 +58,10 @@ int_uint_consts!(u32, 4, u32x4, 128);
 unsafe impl Zeroable for u32x4 {}
 unsafe impl Pod for u32x4 {}
 
+impl AlignTo for u32x4 {
+  type Elem = u32;
+}
+
 impl Add for u32x4 {
   type Output = Self;
   #[inline]
@@ -262,12 +266,12 @@ macro_rules! impl_shl_t_for_u32x4 {
           } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))]{
             unsafe {Self { neon: vshlq_u32(self.neon, vmovq_n_s32(rhs as i32)) }}
           } else {
-            let u = rhs as u64;
+            let u = rhs as u32;
             Self { arr: [
-              self.arr[0] << u,
-              self.arr[1] << u,
-              self.arr[2] << u,
-              self.arr[3] << u,
+              self.arr[0].wrapping_shl(u),
+              self.arr[1].wrapping_shl(u),
+              self.arr[2].wrapping_shl(u),
+              self.arr[3].wrapping_shl(u),
             ]}
           }
         }
@@ -293,12 +297,12 @@ macro_rules! impl_shr_t_for_u32x4 {
           } else if #[cfg(all(target_feature="neon",target_arch="aarch64"))]{
             unsafe {Self { neon: vshlq_u32(self.neon, vmovq_n_s32( -(rhs as i32))) }}
           } else {
-            let u = rhs as u64;
+            let u = rhs as u32;
             Self { arr: [
-              self.arr[0] >> u,
-              self.arr[1] >> u,
-              self.arr[2] >> u,
-              self.arr[3] >> u,
+              self.arr[0].wrapping_shr(u),
+              self.arr[1].wrapping_shr(u),
+              self.arr[2].wrapping_shr(u),
+              self.arr[3].wrapping_shr(u),
             ]}
           }
         }
@@ -380,8 +384,25 @@ impl Shl<u32x4> for u32x4 {
 impl CmpEq for u32x4 {
   type Output = Self;
   #[inline]
-  fn cmp_eq(self, rhs: Self) -> Self::Output {
-    Self::cmp_eq(self, rhs)
+  fn simd_eq(self, rhs: Self) -> Self::Output {
+    Self::simd_eq(self, rhs)
+  }
+}
+
+impl CmpGt for u32x4 {
+  type Output = Self;
+  #[inline]
+  fn simd_gt(self, rhs: Self) -> Self::Output {
+    Self::simd_gt(self, rhs)
+  }
+}
+
+impl CmpLt for u32x4 {
+  type Output = Self;
+  #[inline]
+  fn simd_lt(self, rhs: Self) -> Self::Output {
+    // no gt, so just reverse to get same answer
+    Self::simd_gt(rhs, self)
   }
 }
 
@@ -393,7 +414,7 @@ impl u32x4 {
   }
   #[inline]
   #[must_use]
-  pub fn cmp_eq(self, rhs: Self) -> Self {
+  pub fn simd_eq(self, rhs: Self) -> Self {
     pick! {
       if #[cfg(target_feature="sse2")] {
         Self { sse: cmp_eq_mask_i32_m128i(self.sse, rhs.sse) }
@@ -413,7 +434,7 @@ impl u32x4 {
   }
   #[inline]
   #[must_use]
-  pub fn cmp_gt(self, rhs: Self) -> Self {
+  pub fn simd_gt(self, rhs: Self) -> Self {
     pick! {
       if #[cfg(target_feature="sse2")] {
         // no unsigned less than so inverting the high bit will get the correct result
@@ -435,13 +456,13 @@ impl u32x4 {
   }
   #[inline]
   #[must_use]
-  pub fn cmp_lt(self, rhs: Self) -> Self {
+  pub fn simd_lt(self, rhs: Self) -> Self {
     // lt is just gt the other way around
-    rhs.cmp_gt(self)
+    rhs.simd_gt(self)
   }
 
   /// Multiplies 32x32 bit to 64 bit and then only keeps the high 32 bits of the
-  /// result. Useful for implementing divide constant value (see t_usefulness
+  /// result. Useful for implementing divide constant value (see `t_usefulness`
   /// example)
   #[inline]
   #[must_use]
@@ -495,7 +516,7 @@ impl u32x4 {
   /// on the corresponding lanes.
   ///
   /// Effectively does two multiplies on 128 bit platforms, but is easier
-  /// to use than wrapping mul_widen_u32_odd_m128i individually.
+  /// to use than wrapping `mul_widen_u32_odd_m128i` individually.
   #[inline]
   #[must_use]
   pub fn mul_widen(self, rhs: Self) -> u64x4 {
@@ -660,10 +681,10 @@ impl u32x4 {
         #[inline(always)]
         fn transpose_column(data: &[u32x4; 4], index: usize) -> u32x4 {
           u32x4::new([
-            data[0].as_array_ref()[index],
-            data[1].as_array_ref()[index],
-            data[2].as_array_ref()[index],
-            data[3].as_array_ref()[index],
+            data[0].as_array()[index],
+            data[1].as_array()[index],
+            data[2].as_array()[index],
+            data[3].as_array()[index],
           ])
         }
 
@@ -683,12 +704,12 @@ impl u32x4 {
   }
 
   #[inline]
-  pub fn as_array_ref(&self) -> &[u32; 4] {
+  pub fn as_array(&self) -> &[u32; 4] {
     cast_ref(self)
   }
 
   #[inline]
-  pub fn as_array_mut(&mut self) -> &mut [u32; 4] {
+  pub fn as_mut_array(&mut self) -> &mut [u32; 4] {
     cast_mut(self)
   }
 }
